Example notebooks are stored in `../doc/source/examples/`. 

This directory contains symbolic links to the notebooks, which serve as shortcuts. For example, 
the `cd_mol.ipynb` notebook can be opened by running `jupyer-notebook examples/cd_mol.ipynb` in 
the root directory.

Note: The symbolic links might not work on some Windows versions. 
